# telegram-bell

Notify you when something is mentioned in a telegram channel.

## Install

    pip install telegram-bell

# Usage

    tbell run

Before you can use, it will ask you for:
    
- your Telegram API ID
- your Telegram API hash
- channels and keywords which you want to get notified

Then, the app will resend you the coinciding messages to your 'Saved Messages' channel
in Telegram.